Learn R Programming

caroline (version 0.3-6)

cmdArgsToVariables: Create R variables from command line parameters

Description

Take the names of the variables specified on the R CMD BATCH call and turn them into R variables Assign the values after '=' to these variables.

Usage

cmdArgsToVariables()

Arguments