Learn R Programming

caroline (version 0.3-6)

delist: Convert a named list into new objects in memory.

Description

This function uses the 'assign' function to turn each object element of the list into a new object in the global environment.

Usage

delist(L)

Arguments

L
list of named objects

Value

  • new variables in the global environment

See Also

assign