heatmatrix: Simple Heatmap Plot

View source: R/plots.R

heatmatrixR Documentation

Simple Heatmap Plot

Description

This is a very simplified heat-map function–a convenient wrapper around the 'image' function.

Usage

heatmatrix(x, values=TRUE, clp=c('bottom','top'), rlp=c('left','right'), 
  xadj=.05, yadj=1, ylab.cntr=FALSE, cex=1, axis.cex=1, text.col=1, xlab='',ylab='',...)

Arguments

x

A matrix

values

boolean: should the values be plotted over each cell?

clp

column label position: either 'bottom' or 'top'.

rlp

row label position: either 'right' or 'left'.

xadj

x-adjust of the row labels.

yadj

y-adjust of the column labels.

ylab.cntr

boolean for justification of row labels.

cex

character expansion factor for values in cells if values == TRUE.

axis.cex

character expansion factor for axis tick mark labels.

text.col

color of the text printed over the colored rectangle of all matrix cells.

xlab

x axis label.

ylab

y axis label.

...

other parameters passed on to image().

Value

A heat-map plot.

See Also

image, heatmap, heatmap.2

Examples


data(mtcars)
x  <- as.matrix(mtcars)

heatmatrix(x)


caroline documentation built on July 15, 2026, 9:06 a.m.