Rdocumentation
powered by
Learn R Programming
caroline (version 0.3-6)
pad: Pad a vector of numerical string with zeros.
Description
This function helps to pad numbers on the left side with zeros so that they may be used to create strings used in filesystem names (for example).
Usage
pad(vect,np)
Arguments
vect
a vector of strings representing numbers.
np
number of zeros to pad to the left of the string.