Learn R Programming

caroline (version 0.3-6)

rmFileLock: Remove a Lock File

Description

A function to remove a lock file (a file with the same name + 'LOCK') to indicate the end of exclusive write access of that file by a process. Used in conjunction with getLockFile to lock a file up for one processor at a time in a multiprocessor environment.

Usage

rmFileLock(filepath, id)

Arguments

filepath
The path to the file you wish to lock.
id
unique process identifier

See Also

getFileLock