Learn R Programming

caroline (version 1.1.2)

spie: Spie charts

Description

Spie Chart

Usage

spie(p1, p2, init.angle=pi, multi, col = rainbow(length(x$radii)), bg=col, lwd=2, 
              pie.labs=TRUE, grid=TRUE, grid.labs=TRUE, scale=TRUE, p1.circle=TRUE)

Arguments

p1

a positive numeric vector.

p2

a positive numeric vector. Angles are the same than those used for the first pie but radii change according to the values in p1.

init.angle

initial angle.

multi

radius scale multiplier.

col

colors of the p2 (foreground) slices.

bg

colors of the p1 (background) slices.

lwd

line width of the pie wedge boundaries.

pie.labs

boolean labels for the pies.

grid

boolean.

grid.labs

boolean, scale indicators.

scale

boolean.

p1.circle

boolean.

Author

Romain Francois francoisromain@free.fr & David Schruth code@anthropoidea.org

References

D. G. Feitelson (2003), "Comparing Partitions with Spie Charts". School of Computer Science and Engineering, The Hebrew University of Jerusalem.

Michael Friendly (2022), Spie chart -- a comparison of two pie charts.

See Also

Examples

Run this code

  p1  <- c(0.12, 0.3, 0.26, 0.16, 0.04, 0.12)
  p2<- c(0.06, 0.15, 0.52, 0.14, 0.08, 0.05)
  plot(p1, p2, multi=c(.5, 1, 1.5, 2))

Run the code above in your browser using DataLab