Learn R Programming

caroline (version 0.3-6)

tab2df: Table to Data Frame

Description

Convert a table to a dataframe while perserving the same number of columns and rows and names of each.

Usage

tab2df(x)

Arguments

x
a table class object (output from the table command).

See Also

table

Examples

Run this code
tab2df(table(c(1,2,1,1,1,2,2,2,2),c('a','b','b','a','b','b','a','b','b')))

Run the code above in your browser using DataLab