heatmatrix: Simple Heatmap Plot

View source: R/plots.R

heatmatrixR Documentation

Simple Heatmap Plot

Description

This is a very simplified heatmap function: basically a convienent wrapper around the 'image' function.

Usage

heatmatrix(x, values=TRUE, clp=c('bottom','top'), rlp=c('left','right'), 
  xadj=.05, yadj=1, ylab.cntr=FALSE, cex=1, axis.cex=1, text.col=1, xlab='',ylab='',...)

Arguments

x

A matrix

values

boolean: should the values be plotted over each cell?

clp

column label position: either 'bottom' or 'top'.

rlp

row label position: either 'right' or 'left'

xadj

x-adjust of the row labels

yadj

y-adjust of the column labels.

ylab.cntr

boolean for justification of row labels.

cex

character expansion factor for values in cells if values == true

axis.cex

character expansion factor for axis tick mark labels

text.col

color of the text printed over the colored rectangle of all matrix cells

xlab

x axis label

ylab

y axis label

...

other paramters passed on to image()

Value

a heatmap plot

See Also

image, heatmap, heatmap.2

Examples


data(mtcars)
x  <- as.matrix(mtcars)

heatmatrix(x)


caroline documentation built on July 6, 2026, 9:07 a.m.