powered by
This is a very simplified heat-map function--a convenient wrapper around the 'image' function.
heatmatrix(x, values=TRUE, clp=c('bottom','top'), rlp=c('left','right'), xadj=.05, yadj=1, ylab.cntr=FALSE, cex=1, axis.cex=1, text.col=1, xlab='',ylab='',...)
A heat-map plot.
A matrix
boolean: should the values be plotted over each cell?
column label position: either 'bottom' or 'top'.
row label position: either 'right' or 'left'.
x-adjust of the row labels.
y-adjust of the column labels.
boolean for justification of row labels.
character expansion factor for values in cells if values == TRUE.
character expansion factor for axis tick mark labels.
color of the text printed over the colored rectangle of all matrix cells.
x axis label.
y axis label.
other parameters passed on to image().
image, heatmap, heatmap.2
data(mtcars) x <- as.matrix(mtcars) heatmatrix(x)
Run the code above in your browser using DataLab