This function simply takes the values of the input vector and assigns it to the first column of the dataframe. The second column assigned from the names of this input vectors).
Usage
nv2df(x, clmn.names=c('x','name'), ...)
Value
a two column dataframe with values of x in the first column and the names of x in the second
Author
David Schruth
Arguments
x
a named vector.
clmn.names
a vector of names of the new columns formed by 1) the values and 2) the names of the named vector.