| pct | R Documentation |
This function will add extra columns to an existing dataframe. The second argument 'clmn' should specify which column(s) of the dataframe the percentage should be calculated by dividing each column's row-element by it's sum. If x is not a dataframe, it will attempt to do a simple percentage operation on whatever input was passed to x
pct(x, clmns=NA, digits=2, suffix='%')
x |
A dataframe with numeric columns, or just a single numeric vector |
clmns |
the names of the columns for which the percentage column should be calculated from. |
digits |
number of decimal places for rounding |
suffix |
a character string specifying that the fraction should be converted to a true percentage, as a character string, with a percentage-worthy suffix |
The original dataframe plus extra percentage columns corresponding to original columns in the dataframe.
df <- data.frame(a=c(1,2,3), b=c('x','y','z'), c=c(5,3,2))
pct(df, c('a','c'))
pct(1:10)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.