plotClock: Plot a simple clock.
Description
Used to create a clock on a plot as a way to keep track of the additional
parameter of time for use in animated movies of multiple plots.Usage
plotClock(hour, minute, title, x0 = 0, y0 = 0, r = 1)
Arguments
hour
integer specifying the position of the hour hand.
minute
integer specifying the position of the minute hand.
title
title for the clock.
x0
number specifying the x position of the clock.
y0
number specifying the y position of the clock.
r
number specifying the radius of the clock.