powered by
Spie Chart
spie(p1, p2, init.angle=pi, multi, col = rainbow(length(x$radii)), bg=col, lwd=2, pie.labs=TRUE, grid=TRUE, grid.labs=TRUE, scale=TRUE, p1.circle=TRUE)
a positive numeric vector.
a positive numeric vector. Angles are the same than those used for the first pie but radii change according to the values in p1.
initial angle.
radius scale multiplier.
colors of the p2 (foreground) slices.
colors of the p1 (background) slices.
line width of the pie wedge boundaries.
boolean labels for the pies.
boolean.
boolean, scale indicators.
Romain Francois francoisromain@free.fr & David Schruth code@anthropoidea.org
D. G. Feitelson (2003), "Comparing Partitions with Spie Charts". School of Computer Science and Engineering, The Hebrew University of Jerusalem.
Michael Friendly (2022), Spie chart -- a comparison of two pie charts.
pie
p1 <- c(0.12, 0.3, 0.26, 0.16, 0.04, 0.12) p2<- c(0.06, 0.15, 0.52, 0.14, 0.08, 0.05) plot(p1, p2, multi=c(.5, 1, 1.5, 2))
Run the code above in your browser using DataLab