Rdocumentation
powered by
Learn R Programming
caroline (version 0.3-6)
usr2lims: Grab and adjust the current plot dimensions
Description
This is a simple function which grabs the current plot dimentions and adjusts them by shrinking them by 4
Usage
usr2lims(adj=.04)
Arguments
adj
The automatic adjustment factor 'plot' adds to buffer the specified plot dimentions.
Value
A list of the new xlim and ylim vectors.
See Also
par