| wjitter | R Documentation |
Use weights to jitter values away from their current value.
wjitter(x, w, amount=.43)
x |
a vector of values. |
w |
a vector of weights of the same length as x. |
amount |
the amount to jitter (passed to the parameter by the same name in the jitter function). |
A weighted jittered vector of the same length as x.
x <- seq(1,20)
w <- runif(20, 0,1)
plot(x,wjitter(w,x))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.