powered by
Use weights to jitter values away from their current value.
wjitter(x, w, amount=.43)
A weighted jittered vector of the same length as x.
a vector of values.
a vector of weights of the same length as x.
the amount to jitter (passed to the parameter by the same name in the jitter function).
x <- seq(1,20) w <- runif(20, 0,1) plot(x,wjitter(w,x))
Run the code above in your browser using DataLab